==================
``writing`` module
==================

.. automodule:: whoosh.writing


Writer
======

.. autoclass:: IndexWriter
    :members:


Utility writers
===============

.. autoclass:: BufferedWriter
    :members:

.. autoclass:: AsyncWriter
    :members:

    
Posting writer
==============

.. autoclass:: PostingWriter


Exceptions
==========

.. autoexception:: IndexingError


